@@ -1,13 +1,8 @@
 use strict;
 use warnings;
-package Acme::Pi;
-BEGIN {
-  $Acme::Pi::AUTHORITY = 'cpan:ETHER';
-}
-# git description: v3.1-10-g4f34aed
-
+package Acme::Pi; # git description: v3.14-11-g0c6a7eb
 # ABSTRACT: Mmm, pie
-# vim: set ts=8 sw=4 tw=78 et :
+# vim: set ts=8 sts=4 sw=4 tw=78 et :
 
 use utf8;
 # KEYWORDS: pi π
@@ -42,6 +37,10 @@ It defines its version as:
 
     atan2(1,1) * 4;
 
+It is intended that version parsers in the toolchain (L<Module::Metadata>,
+L<ExtUtils::MakeMaker>'s C<< MM->parse_version >>, L<Parse::PMFile>) should
+be capable of statically parsing this package's <$VERSION>.
+
 =head1 SUPPORT
 
 =for stopwords irc
